# Tweepipe

Easy data collection from Twitter and storage to MongoDB.

## Quick Start

You'll need python 3.8 to install install `tweepipe` with pip:

```bash
pip install tweepipe
```

## Contribution guidelines

- Start a new feature branch from the main git branch. Give it a meaningful name.
- Write your code.
- Add unit tests.

## Maintainers

- [Sacha Lévy](https://twitter.com/sachalevy3) (sacha.levy@mail.mcgill.ca)
